From 738cdfad8812afeb274fd00f473a5c2f4c6b4318 Mon Sep 17 00:00:00 2001
From: Enji Cooper <yaneurabeya@gmail.com>
Date: Wed, 5 Jun 2024 20:11:36 -0700
Subject: [PATCH 2/3] createNodesByOidString: guard against a NULL pointer
 deref

In the event an invalid value for `oid` was passed (or one that was an
OID root), the code would crash accessing invalid memory (a NULL
pointer) when calling strtoul.

This change modifies the code to be more defensive by guarding the loop
with a precondition instead of a post-condition, similar to other
functions in the file.

Reported by:	Coverity
Signed-off-by: Enji Cooper <yaneurabeya@gmail.com>
---
 lib/smi-data.c | 6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

diff --git a/lib/smi-data.c b/lib/smi-data.c
index 60ce8d5c..797f618d 100644
--- a/lib/smi-data.c
+++ b/lib/smi-data.c
@@ -1144,16 +1144,14 @@ Node *createNodesByOidString(const char *oid)
     parentNodePtr = smiHandle->rootNodePtr;
     elements = smiStrdup(oid);
 
-    p = strtok(elements, ".");
-    do {
+    while (!(p = strtok(NULL, "."))) {
 	subid = (unsigned int)strtoul(p, NULL, 0);
 	if (!(nodePtr = findNodeByParentAndSubid(parentNodePtr,
 						 subid))) {
 	    nodePtr = addNode(parentNodePtr, subid, 0, NULL);
 	}
 	parentNodePtr = nodePtr;
-    } while ((p = strtok(NULL, ".")));
-
+    }
     smiFree(elements);
 
     return parentNodePtr;
-- 
2.45.1

